@@ -336,7 +336,10 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         return distinct_field_ls
 
     def get_base_fields(self):
-        return self.base_fields
+        query_dc = self.get_request_data()
+        base_fields = get_list(query_dc, 'base_fields')
+        base_fields = base_fields if base_fields else self.base_fields
+        return base_fields
 
     def get_retrieve_ret(self, request: Request, *args, **kwargs):
         """
@@ -511,7 +514,8 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         query_dc = self.get_request_data()
         page_size = query_dc.get('page_size', self.pagination_class.page_size)
         p = query_dc.get('p', 1)
-        resp, page_dc = paginate_qsls_to_dcls(self.queryset, self.get_serializer_class(), page=p, per_page=page_size)
+        context = self.get_serializer_context()
+        resp, page_dc = paginate_qsls_to_dcls(self.queryset, self.get_serializer_class(), page=p, per_page=page_size, context=context)
         ret = self._conv_data_format(resp, page_dc)
         return ret
 
@@ -608,7 +612,7 @@ def get_base_queryset(obj) -> QuerySet:
     return ret
 
 
-def paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16):
+def paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16, context=None):
     """
     * 手动分页函数
 
@@ -631,9 +635,12 @@ def paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16):
 
     # --- 处理单个Model和多个Model的情况
     if serializer.__class__.__name__ == 'function':
-        dc_ls = serializer(page_obj)
+        try:
+            dc_ls = serializer(page_obj, context=context)
+        except Exception as e:
+            print('--- paginate_qsls_to_dcls错误!!! 2022/2/25')
     else:
-        dc_ls = serializer(page_obj, many=True).data
+        dc_ls = serializer(page_obj, many=True, context=context).data
     return dc_ls, page_dc
 
 
